@@ -1,15 +1,26 @@
 package main
 
 import (
-	"io/ioutil"
+	"fmt"
+	"log"
 	"os"
 	"os/exec"
+	"os/user"
 	"path"
+	"path/filepath"
 	"strings"
 
 	"gopkg.in/yaml.v2"
 )
 
+type ConfigNotFoundError struct {
+	Project string
+}
+
+func (e ConfigNotFoundError) Error() string {
+	return fmt.Sprintf("config not found for project %s", e.Project)
+}
+
 type Pane struct {
 	Root     string   `yaml:"root,omitempty"`
 	Type     string   `yaml:"type,omitempty"`
@@ -27,12 +38,14 @@ type Window struct {
 }
 
 type Config struct {
-	Session     string            `yaml:"session"`
-	Env         map[string]string `yaml:"env"`
-	Root        string            `yaml:"root"`
-	BeforeStart []string          `yaml:"before_start"`
-	Stop        []string          `yaml:"stop"`
-	Windows     []Window          `yaml:"windows"`
+	SendKeysTimeout int    `yaml:"sendkeys_timeout"`
+	Session         string `yaml:"session"`
+	TmuxOptions     `yaml:"tmux_options"`
+	Env             map[string]string `yaml:"env"`
+	Root            string            `yaml:"root"`
+	BeforeStart     []string          `yaml:"before_start"`
+	Stop            []string          `yaml:"stop"`
+	Windows         []Window          `yaml:"windows"`
 }
 
 func addDefaultEnvs(c *Config, path string) {
@@ -54,8 +67,26 @@ func EditConfig(path string) error {
 	return cmd.Run()
 }
 
-func GetConfig(path string, settings map[string]string) (*Config, error) {
-	f, err := ioutil.ReadFile(path)
+func setTmuxOptions(tmuxOpts *TmuxOptions, c Config) {
+	tmuxOpts.SocketName = c.SocketName
+	tmuxOpts.SocketPath = c.SocketPath
+
+	if c.ConfigFile != "" {
+		usr, err := user.Current()
+		if err != nil {
+			log.Fatalf("cannot expand user home dir: %s",  err)
+		}
+		path := c.ConfigFile
+		if strings.HasPrefix(path,"~") {
+			path = filepath.Join(usr.HomeDir, path[1:])
+		}
+
+		tmuxOpts.ConfigFile = path
+	}
+}
+
+func GetConfig(path string, settings map[string]string, tmuxOpts *TmuxOptions) (*Config, error) {
+	f, err := os.ReadFile(path)
 	if err != nil {
 		return nil, err
 	}
@@ -68,6 +99,7 @@ func GetConfig(path string, settings map[string]string) (*Config, error) {
 	}
 
 	addDefaultEnvs(&c, path)
+	setTmuxOptions(tmuxOpts, c)
 
 	return &c, err
 
@@ -100,7 +132,7 @@ func ParseConfig(data string, settings map[string]string) (Config, error) {
 
 func ListConfigs(dir string) ([]string, error) {
 	var result []string
-	files, err := ioutil.ReadDir(dir)
+	files, err := os.ReadDir(dir)
 
 	if err != nil {
 		return result, err
@@ -108,11 +140,27 @@ func ListConfigs(dir string) ([]string, error) {
 
 	for _, file := range files {
 		fileExt := path.Ext(file.Name())
-		if fileExt != ".yml" {
+		if fileExt != ".yml" && fileExt != ".yaml" {
 			continue
 		}
-		result = append(result, strings.TrimSuffix(file.Name(), fileExt))
+		result = append(result, file.Name())
 	}
 
 	return result, nil
 }
+
+func FindConfig(dir, project string) (string, error) {
+	configs, err := ListConfigs(dir)
+	if err != nil {
+		return "", err
+	}
+
+	for _, config := range configs {
+		fileExt := path.Ext(config)
+		if strings.TrimSuffix(config, fileExt) == project {
+			return config, nil
+		}
+	}
+
+	return "", ConfigNotFoundError{Project: project}
+}
