@@ -9,6 +9,11 @@ import (
 func TestParseConfig(t *testing.T) {
 	yaml := `
 session: ${session}
+sendkeys_timeout: 200
+tmux_options:
+    socket_name: foo
+    socket_path: /path/to/socket
+    config_file: /path/to/tmux_config
 windows:
   - layout: tiled
     commands:
@@ -27,8 +32,14 @@ windows:
 	}
 
 	expected := Config{
-		Session: "test",
-		Env:     make(map[string]string),
+		Session:         "test",
+		SendKeysTimeout: 200,
+		Env:             make(map[string]string),
+		TmuxOptions: TmuxOptions{
+			SocketName: "foo",
+			SocketPath: "/path/to/socket",
+			ConfigFile: "/path/to/tmux_config",
+		},
 		Windows: []Window{
 			{
 				Layout:   "tiled",
